#!/bin/bash
#
# Functions defined in this file are used by OpenStack Nova scripts

CONFIG=/etc/nova/nova.conf

daemon_status() {
	ps -C $DAEMON -o cmd= | grep -v defunct > /dev/null
	return $?
}

start() {
	local DAEMON NAME PIDFILE LOCKFILE LOGFILE
	DAEMON=nova-$1
	NAME=$2
	PIDFILE=/var/run/nova/$DAEMON.pid
	LOCKFILE=/var/lock/subsys/$DAEMON
	LOGFILE=/var/log/nova/$1

	daemon_status
	RETVAL=$?
	if [ $RETVAL -eq 0 ]; then
		msg_already_running "$NAME"
		passed
		echo
		return 1
	fi
	mkdir -p /var/run/nova
	start_daemon --user nova --make-pidfile --pidfile $PIDFILE \
		--displayname "$NAME" $DAEMON
	RETVAL=$?
	[ $RETVAL -eq 0 ] && touch $LOCKFILE ||\
		RETVAL=1
	return $RETVAL
}

stop() {
	local DAEMON NAME PIDFILE LOCKFILE LOGFILE
	DAEMON=nova-$1
	NAME=$2
	PIDFILE=/var/run/nova/$DAEMON.pid
	LOCKFILE=/var/lock/subsys/$DAEMON

	daemon_status
	RETVAL=$?
	if [ $RETVAL -eq 1 ]; then
		msg_not_running "$NAME"
		passed
		echo
		return 1
	fi
	msg_stopping "$NAME"
	start-stop-daemon --stop --pidfile $PIDFILE > /dev/null
	RETVAL=$?
	if [ $RETVAL -eq 0 ]; then
		success
	else
		failure
	fi
	echo
	[ $RETVAL -eq 0 ] && rm -f $LOCKFILE && rm -f $PIDFILE
	sleep 0.1
	return $RETVAL
}

restart() {
	stop $1 "$2"
	start $1 "$2"
}

status() {
	local DAEMON NAME PIDFILE LOCKFILE LOGFILE
	DAEMON=nova-$1
	NAME=$2

	daemon_status
	RETVAL=$?
	if [ $RETVAL -eq 0 ]; then
		msg_already_running "$NAME"
	else
		msg_not_running "$NAME"
	fi
	echo
	return $RETVAL
}
